
local screenWidth, screenHeight = love.graphics.getDimensions()
local borderSize
local rect = {}

function love.load()
  borderSize = love.math.random(8, 128)
  rect.width = love.math.random(8, 64)
  rect.height = rect.width
  rect.x = screenWidth/2-rect.width/2
  rect.y = screenHeight/2-rect.height/2
  rect.speed = 400
end


function rect.update(dt)
  local keyDown = love.keyboard.isDown
  if keyDown("left") then rect.x = rect.x - rect.speed * dt end
  if keyDown("right") then rect.x = rect.x + rect.speed * dt end
  if keyDown("up") then rect.y = rect.y - rect.speed * dt end
  if keyDown("down") then rect.y = rect.y + rect.speed * dt end
  rect.x = math.max(rect.x, borderSize)
  rect.x = math.min(rect.x, screenWidth-rect.width-borderSize)
  rect.y = math.max(rect.y, borderSize)
  rect.y = math.min(rect.y, screenHeight-rect.height-borderSize)
end


function rect.draw()
  love.graphics.rectangle("fill", rect.x, rect.y, rect.width, rect.height)
end


function love.update(dt)
  -- Reduce border Size --
  if screenHeight-(borderSize*2) > rect.width then
    borderSize = borderSize + 20 * dt
  end
  rect.update(dt)
end


function love.draw()
  love.graphics.rectangle("line", borderSize, borderSize, screenWidth-(borderSize*2), screenHeight-(borderSize*2))
  rect.draw()
  love.graphics.print("Space - Resize Border/Player", 10, 10)
  love.graphics.print("Arrow Keys - Move", 10, 30)
  love.graphics.print("Escape - Quit", 10, 50)
end


function love.keypressed(key)
  if key == "escape" then love.event.quit()
  elseif key == "space" then love.load() end
end
